==> mingw-w64-starpu-1.4.7-3.src.tar.zst: starpu-1.4.7/doc/doxygen_dev/html_dev/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Internal Handbook", "index.html", [
    [ "Introduction", "index.html", [
      [ "Motivation", "index.html#Motivation", null ]
    ] ],
    [ "StarPU Core", "StarPUCore.html", [
      [ "StarPU Core Entities", "StarPUCore.html#CoreEntities", [
        [ "Overview", "StarPUCore.html#CoreEntitiesOverview", null ],
        [ "Workers", "StarPUCore.html#CoreEntitiesWorkers", [
          [ "States", "StarPUCore.html#CoreEntitiesWorkersStates", null ],
          [ "Operations", "StarPUCore.html#CoreEntitiesWorkersOperations", null ]
        ] ],
        [ "Scheduling Contexts", "StarPUCore.html#CoreEntitiesContexts", null ],
        [ "Workers and Scheduling Contexts", "StarPUCore.html#CoreEntitiesWorkersAndContexts", null ],
        [ "Drivers", "StarPUCore.html#CoreEntitiesDrivers", [
          [ "Master/Slave Drivers", "StarPUCore.html#CoreEntitiesDriversMP", null ]
        ] ],
        [ "Tasks and Jobs", "StarPUCore.html#CoreEntitiesTasksJobs", null ],
        [ "Data", "StarPUCore.html#CoreEntitiesData", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"StarPUCore.html",
"errorcheck_8h.html#a9a68eae2e97c3c7c544cd069073a8a06",
"group__workers.html",
"sched__ctx__list_8h.html#struct__starpu__sched__ctx__list",
"structstarpu__transaction.html#abce904c56c953573ca433a5d231af4c1"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.9-1.src.tar.zst: starpu-1.4.9/doc/doxygen_dev/html_dev/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Internal Handbook", "index.html", [
    [ "Introduction", "index.html", [
      [ "Motivation", "index.html#Motivation", null ]
    ] ],
    [ "StarPU Core", "StarPUCore.html", [
      [ "StarPU Core Entities", "StarPUCore.html#CoreEntities", [
        [ "Overview", "StarPUCore.html#CoreEntitiesOverview", null ],
        [ "Workers", "StarPUCore.html#CoreEntitiesWorkers", [
          [ "States", "StarPUCore.html#CoreEntitiesWorkersStates", null ],
          [ "Operations", "StarPUCore.html#CoreEntitiesWorkersOperations", null ]
        ] ],
        [ "Scheduling Contexts", "StarPUCore.html#CoreEntitiesContexts", null ],
        [ "Workers and Scheduling Contexts", "StarPUCore.html#CoreEntitiesWorkersAndContexts", null ],
        [ "Drivers", "StarPUCore.html#CoreEntitiesDrivers", [
          [ "Master/Slave Drivers", "StarPUCore.html#CoreEntitiesDriversMP", null ]
        ] ],
        [ "Tasks and Jobs", "StarPUCore.html#CoreEntitiesTasksJobs", null ],
        [ "Data", "StarPUCore.html#CoreEntitiesData", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"StarPUCore.html",
"errorcheck_8h.html#a9a68eae2e97c3c7c544cd069073a8a06",
"group__workers.html",
"sched__ctx__list_8h.html#struct__starpu__sched__ctx__elt",
"structstarpu__transaction.html#a5fd26eb2d9269aff1fb3bcf0c772a710"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
